@@ -4,19 +4,22 @@ from algora.common.config import EnvironmentConfig
 
 config = EnvironmentConfig()
 
-def _login_request_info(username: str, password: str, scope: Optional[str] = None) -> dict:
+
+def _login_request_info(
+    username: str, password: str, scope: Optional[str] = None
+) -> dict:
     data = {
         "client_id": "algora-api",
         "grant_type": "password",
         "username": username,
-        "password": password
+        "password": password,
     }
     if scope is not None:
-        data.update({'scope': scope})
+        data.update({"scope": scope})
 
     return {
         "url": f"{config.get_url('keycloak')}/protocol/openid-connect/token",
-        "data": data
+        "data": data,
     }
 
 
@@ -26,8 +29,8 @@ def _refresh_token_request_info(refresh_token: Optional[str] = None) -> dict:
         "data": {
             "client_id": "algora-api",
             "grant_type": "refresh_token",
-            "refresh_token": refresh_token
-        }
+            "refresh_token": refresh_token,
+        },
     }
 
 
@@ -37,10 +40,10 @@ def _token_exchange_request_info(requested_subject: str, subject_token: str) ->
         "grant_type": "urn:ietf:params:oauth:grant-type:token-exchange",
         "requested_subject": requested_subject,
         "subject_token": subject_token,
-        "scope": "offline_access"
+        "scope": "offline_access",
     }
 
     return {
         "url": f"{config.get_url('keycloak')}/protocol/openid-connect/token",
-        "data": data
+        "data": data,
     }
