@@ -3,7 +3,7 @@ from functools import cached_property, cache
 from typing import Optional
 
 from algora.common.date.calendar.market_calendar import MarketCalendar
-from algora.quant.model.enum import WeekdayCorrection
+from algora.quant.model.enum import BusinessDayConvention
 from algora.quant.model.period import Period
 
 
@@ -14,14 +14,14 @@ class Schedule:
         end_date: date,
         calendar: MarketCalendar,
         period: Period,
-        convention: WeekdayCorrection,
+        convention: BusinessDayConvention,
     ):
         self._start_date: date = start_date
         self._end_date: date = end_date
 
         self._calendar: MarketCalendar = calendar
         self._period: Period = period
-        self._convention: WeekdayCorrection = convention
+        self._convention: BusinessDayConvention = convention
 
         self._last: Optional[date] = None
         self._current: date = self._start_date
