@@ -1,5 +1,7 @@
 """
 Authenticated request decorators.
 """
-from algora.common.decorators.authorization.asynchronous import async_authenticated_request
+from algora.common.decorators.authorization.asynchronous import (
+    async_authenticated_request,
+)
 from algora.common.decorators.authorization.synchronous import authenticated_request
