@@ -48,8 +48,8 @@ def coalesce_callables(*args):
 
 
 def transform_one_or_many(
-        data: Union[List[Dict[str, Any]], Dict[str, List[Dict[str, Any]]]],
-        key: Optional[str] = None
+    data: Union[List[Dict[str, Any]], Dict[str, List[Dict[str, Any]]]],
+    key: Optional[str] = None,
 ) -> Union[DataFrame, Dict[str, DataFrame]]:
     """
     Converts data to a dataframe or multiple dataframes.
@@ -69,7 +69,7 @@ def transform_one_or_many(
     return DataFrame(data)
 
 
-def to_pandas_with_index(data: Dict[str, Any], index: str = 'date') -> DataFrame:
+def to_pandas_with_index(data: Dict[str, Any], index: str = "date") -> DataFrame:
     """
     Transform input data into pandas dataframe and assign index.
 
@@ -108,7 +108,9 @@ def data_required_transform(data: Dict[str, Any]) -> Dict[str, Any]:
         Dict[str, Any]: Output data
     """
     if len(data) <= 0:
-        raise ApiError(f'There are no results for the data you are querying at this time')
+        raise ApiError(
+            f"There are no results for the data you are querying at this time"
+        )
 
     return data
 
@@ -134,7 +136,7 @@ async def build_response_obj(aio_response: ClientResponse) -> Response:
     return response
 
 
-def to_nested_dict(data, separator='.'):
+def to_nested_dict(data, separator="."):
     """
     This method takes a dict and splits keys by the seperator to create a nested dict
 
